@@ -7,7 +7,7 @@
 int main(int argc, char *argv[])
 {
     FILE *file;
-    char line[1024];
+    char line[1<<13];
     size_t len;
 
     if (!(file = fdzopen(fileno(stdin), "r", argc > 1 ? argv[1] : "g"))) {
